pdr: Rename pldm_entity_association_tree_find_if_remote()

Rename pldm_entity_association_tree_find_if_remote() to
pldm_entity_association_tree_find_with_locality(), instead of
being specific on remote entity, rather keeping it generic.

Discussion at https://gerrit.openbmc.org/c/openbmc/libpldm/+/65481/7/src/pdr.c

Change-Id: Icb89d6919d8a2cba6fbba216dd2be70637ba0216
Signed-off-by: Sagar Srinivas <sagar.srinivas@ibm.com>
diff --git a/include/libpldm/pdr.h b/include/libpldm/pdr.h
index d9e2553..4293d75 100644
--- a/include/libpldm/pdr.h
+++ b/include/libpldm/pdr.h
@@ -530,20 +530,20 @@
 pldm_entity_association_tree_find(pldm_entity_association_tree *tree,
 				  pldm_entity *entity);
 
 /** @brief Find an entity in the entity association tree if remote
  *
  *  @param[in] tree - pointer to entity association tree
  *  @param[in/out] entity - entity type and instance id set on input, container
  *                          id set on output
- *  @param[in] is_remote - variable to denote whether we are finding a host
- *                         entity or a BMC entity
+ *  @param[in] is_remote - variable to denote whether we are finding a remote
+ *                         entity or a local entity
  *
  *  @return pldm_entity_node* pointer to entity if found, NULL otherwise
  */
-pldm_entity_node *
-pldm_entity_association_tree_find_if_remote(pldm_entity_association_tree *tree,
-					    pldm_entity *entity,
-					    bool is_remote);
+pldm_entity_node *pldm_entity_association_tree_find_with_locality(
+	pldm_entity_association_tree *tree, pldm_entity *entity,
+	bool is_remote);
 
 /** @brief Create a copy of an existing entity association tree
  *
@@ -530,20 +530,20 @@
 				  pldm_entity *entity);
 
-/** @brief Find an entity in the entity association tree if remote
+/** @brief Find an entity in the entity association tree with locality specified,
+ *         ie - remote entity or local entity
  *
  *  @param[in] tree - pointer to entity association tree